# Release History

## [0.0.7] - Unreleased
### Updated
* Moved numpy to optional dependency
* Python support for 3.12 and 3.13

## [0.0.6] - 2024-02-24
### Added
* Planck constant

## [0.0.5] - 2024-02-23
### Added
* n/a
### Fixed
* n/a
### Updated
* n/a
### Breaking changes
* n/a

## [0.0.4] - 2024-02-23
### Updated
* Documentation branding design

## [0.0.3] - 2023-12-16
### Added
* Example for convert function
### Breaking changes
* Renamed arguments for convert function

## [0.0.2] - 2023-12-15
### Added
* Physical Constants
* Units

## [0.0.1] - 2023-12-13
### Added
* Initial release
